#!/bin/bash

get_rdk_type_string() {
	board_id=$(cat /sys/class/boardinfo/adc_boardid)
	if [[ "$board_id" =~ ^0x(64|65|6A|6B)[0678][0456]$ ]];then
		case ${board_id} in
		*"4")
			echo "s100_v0p5_rdk"
			;;
		*"5")
			echo "s100_v0p6_rdk"
			;;
		*"6")
			echo "s100_v1p0_rdk"
			;;
		*)
			echo "null"
			;;
		esac
	else
		case $board_id in
		"0x301")
			echo "x5_rdk"
			;;
		"0x302")
			echo "x5_rdk"
			;;
		*)
			echo "null"
			exit 1
		;;
		esac
	fi
}

board_type_string=$(get_rdk_type_string)

id messagebus >& /dev/null
if [ $? -ne 0 ]; then
	groupadd  messagebus
	useradd -g messagebus messagebus
fi

if [ $board_type_string == "x5_rdk" ]; then
	hciattach -s 1500000 /dev/ttyS5 any 1500000 noflow &
elif [ $board_type_string == "s100_v0p5_rdk" ] || \
	 [ $board_type_string == "s100_v0p6_rdk" ] || \
	 [ $board_type_string == "s100_v1p0_rdk" ]; then
	BT_REG_ON_GPIO="427"
	BT_TTY_PORT="/dev/ttyS1"
	BT_BAUD="921600"
	export MBT_TRANSPORT="$BT_TTY_PORT"
	if [ ! -d /sys/class/gpio/gpio${BT_REG_ON_GPIO} ];then
		echo "$BT_REG_ON_GPIO" > /sys/class/gpio/export
	fi
	echo "out" > /sys/class/gpio/gpio${BT_REG_ON_GPIO}/direction
	echo 0 > /sys/class/gpio/gpio${BT_REG_ON_GPIO}/value
	sleep 0.5
	echo 1 > /sys/class/gpio/gpio${BT_REG_ON_GPIO}/value
	echo "Start XM612 BT Firmware Download..."
	/bin/mbt download /lib/firmware/cypress/CYW55560A1.hcd --autobaud3M
	/bin/mbt update_baudrate ${BT_BAUD}
	sleep 1
	(set -x; hciattach -s ${BT_BAUD} ${BT_TTY_PORT} any ${BT_BAUD})
else
	echo
fi

echo -n "Waiting for bluetooth initialize..."
wait_hci0=0
while true
do
	[ -d /sys/class/bluetooth/hci0 ] && break
	sleep 1
	let wait_hci0++
	[ $wait_hci0 -eq 30 ] && {
		echo "bring up bluetooth hci0 failed"
		exit 1
	}
	echo -n "."
done

echo "Done"

echo -n "Check Bluetooth State..."
block_state=`rfkill | grep bluetooth | awk '{print $4}'`
echo ${block_state}
if [ x${block_state} == x"blocked" ]; then
	echo "Unblock bluetooth..."
	rfkill unblock bluetooth
fi

sleep 0.3
echo "Set Bluetooth Up..."
hciconfig hci0 up

hciconfig  | grep PSCAN > /dev/null
if [ $? -ne 0 ]; then
	echo "Set Bluetooth piscan..."
	hciconfig hci0 piscan
fi

hciconfig
